@@ -11,6 +11,8 @@
 #'   based on absolute ordered variable loading for each PC in the biplot.
 #'   As a result of looking across 2 PCs, it can occur whereby greater than
 #'   this number are actually displayed.
+#' @param LoadingsNames Names of variable loadings to display. If provided,
+#'   this overrides 'ntopLoadings'.
 #' @param showLoadingsNames Logical, indicating to show variable loadings names
 #'   or not.
 #' @param colLoadingsNames If 'showLoadings == TRUE', colour of text labels.
@@ -98,7 +100,7 @@
 #' @param ellipseLineCol Colour of the ellipse line when 'ellipse == TRUE'.
 #' @param xlim Limits of the x-axis.
 #' @param ylim Limits of the y-axis.
-#' @param lab A vector containing labels to add to the plot. 
+#' @param lab A vector containing labels to add to the plot.
 #' @param labSize Size of labels.
 #' @param boxedLabels Logical, draw text labels in boxes.
 #' @param selectLab A vector containing a subset of lab to plot.
@@ -150,6 +152,7 @@
 #' @param borderColour Colour of the border on the x and y axes.
 #' @param returnPlot Logical, indicating whether or not to return the plot
 #'   object.
+#' @param flip_axes Logical, indicating whether to swap the x- and y-axes.
 #'
 #' @details Draw a bi-plot, comparing 2 selected principal components / eigenvectors.
 #'
@@ -206,6 +209,7 @@ biplot <- function(
   y = 'PC2',
   showLoadings = FALSE,
   ntopLoadings = 5,
+  LoadingsNames = NULL,
   showLoadingsNames = if (showLoadings) TRUE else FALSE,
   colLoadingsNames = 'black',
   sizeLoadingsNames = 3,
@@ -293,7 +297,8 @@ biplot <- function(
   gridlines.minor = TRUE,
   borderWidth = 0.8,
   borderColour = 'black',
-  returnPlot = TRUE)
+  returnPlot = TRUE,
+  flip_axes = FALSE)
 {
 
   labFun <- xidx <- yidx <- NULL
@@ -367,8 +372,8 @@ biplot <- function(
   }
 
   # create the plot object
-  plot <- ggplot(plotobj, aes(x = x, y = y)) + th +
-
+  xy_aes <- if (flip_axes) aes(x = y, y = x) else aes(x = x, y = y)
+  plot <- ggplot(plotobj, xy_aes) + th +
     guides(fill = guide_legend(),
       shape = guide_legend(),
       colour = guide_legend(override.aes = list(size = legendIconSize)))
@@ -405,12 +410,22 @@ biplot <- function(
 
   # plot loadings arrows?
   if (showLoadings) {
-    # get top ntopLoadings to display
+    # get top ntopLoadings to display, or use user-supplied LoadingsNames
     xidx <- order(abs(pcaobj$loadings[,x]), decreasing = TRUE)
     yidx <- order(abs(pcaobj$loadings[,y]), decreasing = TRUE)
-    vars <- unique(c(
-      rownames(pcaobj$loadings)[xidx][seq_len(ntopLoadings)],
-      rownames(pcaobj$loadings)[yidx][seq_len(ntopLoadings)]))
+    if (!is.null(LoadingsNames)) {
+      # validate provided names exist in loadings
+      missing.names <- setdiff(LoadingsNames, rownames(pcaobj$loadings))
+      if (length(missing.names) > 0) {
+        stop(paste0('The following LoadingsNames are not present in pcaobj$loadings: ',
+          paste(missing.names, collapse = ', ')))
+      }
+      vars <- unique(LoadingsNames)
+    } else {
+      vars <- unique(c(
+        rownames(pcaobj$loadings)[xidx][seq_len(ntopLoadings)],
+        rownames(pcaobj$loadings)[yidx][seq_len(ntopLoadings)]))
+    }
 
     # get scaling parameter to match between variable loadings and rotated loadings
     r <- min(
@@ -500,7 +515,7 @@ biplot <- function(
   # add elements to the plot for title, subtitle, caption, and legend titles
   plot <- plot + labs(title = title, 
     subtitle = subtitle, caption = caption,
-    fill = '', colour = colLegendTitle, shape = shapeLegendTitle)
+    fill = NULL, colour = colLegendTitle, shape = shapeLegendTitle)
 
   # add elements to the plot for vlines and hlines
   if (!is.null(vline)) {
@@ -521,7 +536,7 @@ biplot <- function(
     theme(panel.border = element_rect(
       colour = borderColour,
       fill = NA,
-      size = borderWidth))
+      linewidth = borderWidth))
 
   # gridlines
   if (gridlines.major == TRUE) {
